@@ -180,19 +180,19 @@ describe("sinonSpy.call", function() {
                 return spy.getCall(idx);
             });
 
-            assert.equals(calls[1].calledBefore(calls[3]), true);
-            assert.equals(calls[1].calledBefore(calls[0]), false);
+            assert.isTrue(calls[1].calledBefore(calls[3]));
+            assert.isFalse(calls[1].calledBefore(calls[0]));
 
-            assert.equals(calls[3].calledAfter(calls[1]), true);
-            assert.equals(calls[1].calledAfter(calls[3]), false);
+            assert.isTrue(calls[3].calledAfter(calls[1]));
+            assert.isFalse(calls[1].calledAfter(calls[3]));
 
-            assert.equals(calls[0].calledImmediatelyBefore(calls[2]), false);
-            assert.equals(calls[1].calledImmediatelyBefore(calls[2]), true);
-            assert.equals(calls[3].calledImmediatelyBefore(calls[1]), false);
+            assert.isFalse(calls[0].calledImmediatelyBefore(calls[2]));
+            assert.isTrue(calls[1].calledImmediatelyBefore(calls[2]));
+            assert.isFalse(calls[3].calledImmediatelyBefore(calls[1]));
 
-            assert.equals(calls[3].calledImmediatelyAfter(calls[1]), false);
-            assert.equals(calls[2].calledImmediatelyAfter(calls[1]), true);
-            assert.equals(calls[1].calledImmediatelyAfter(calls[3]), false);
+            assert.isFalse(calls[3].calledImmediatelyAfter(calls[1]));
+            assert.isTrue(calls[2].calledImmediatelyAfter(calls[1]));
+            assert.isFalse(calls[1].calledImmediatelyAfter(calls[3]));
         });
     });
 
@@ -552,6 +552,24 @@ describe("sinonSpy.call", function() {
         });
     });
 
+    describe(".firstArg", function() {
+        it("should be the first argument from the call", function() {
+            var spy = sinonSpy();
+
+            spy(41, 42, 43);
+            assert.equals(spy.getCall(0).firstArg, 41);
+
+            spy(44, 45);
+            assert.equals(spy.getCall(1).firstArg, 44);
+
+            spy(46);
+            assert.equals(spy.getCall(2).firstArg, 46);
+
+            spy();
+            assert.isUndefined(spy.getCall(3).firstArg);
+        });
+    });
+
     describe(".lastArg", function() {
         it("should be the last argument from the call", function() {
             var spy = sinonSpy();
